@@ -92,5 +92,8 @@ class MultilingualQuerySet(models.query.QuerySet):
 class MultilingualManager(models.Manager):
     use_for_related_fields = True
 
-    def get_query_set(self):
+    def get_queryset(self):
         return MultilingualQuerySet(self.model)
+
+    def get_query_set(self):  # For Django < 1.6 compatibility
+        return self.get_queryset()
