@@ -4,24 +4,23 @@ from django.db import models
 from django.db.models.base import ModelBase
 from django.conf import settings
 from django.utils.translation import ugettext_lazy as _
-from django.utils.translation import get_language
 
 from linguo.exceptions import MultilingualFieldError
 from linguo.managers import MultilingualManager
-from linguo.utils import get_real_field_name
+from linguo.utils import get_real_field_name, get_normalized_language, get_current_language
 
 
 class MultilingualModelBase(ModelBase):
 
     def __new__(cls, name, bases, attrs):
         local_trans_fields, inherited_trans_fields = \
-            MultilingualModelBase.get_trans_fields(name, bases, attrs)
+            cls.get_trans_fields(name, bases, attrs)
 
         if ('Meta' in attrs) and hasattr(attrs['Meta'], 'translate'):
             delattr(attrs['Meta'], 'translate')
 
-        attrs = MultilingualModelBase.rewrite_trans_fields(local_trans_fields, attrs)
-        attrs = MultilingualModelBase.rewrite_unique_together(local_trans_fields, attrs)
+        attrs = cls.rewrite_trans_fields(local_trans_fields, attrs)
+        attrs = cls.rewrite_unique_together(local_trans_fields, attrs)
 
         new_obj = super(MultilingualModelBase, cls).__new__(cls, name, bases, attrs)
         new_obj._meta.translatable_fields = inherited_trans_fields + local_trans_fields
@@ -36,11 +35,13 @@ class MultilingualModelBase(ModelBase):
 
             # Some fields add a descriptor (ie. FileField), we want to keep that on the model
             if field_name in new_obj.__dict__:
-                primary_lang_field_name = '%s_%s' % (field_name, settings.LANGUAGES[0][0])
+                primary_lang_field_name = '%s_%s' % (
+                    field_name, get_normalized_language(settings.LANGUAGES[0][0])
+                )
                 setattr(new_obj, primary_lang_field_name, new_obj.__dict__[field_name])
 
-            getter = MultilingualModelBase.generate_field_getter(field_name)
-            setter = MultilingualModelBase.generate_field_setter(field_name)
+            getter = cls.generate_field_getter(field_name)
+            setter = cls.generate_field_setter(field_name)
             setattr(new_obj, field_name, property(getter, setter))
 
         return new_obj
@@ -102,7 +103,7 @@ class MultilingualModelBase(ModelBase):
     def generate_field_getter(cls, field):
         # Property that masks the getter of a translatable field
         def getter(self_reference):
-            lang = self_reference._force_language or get_language().split('-')[0]
+            lang = self_reference._force_language or get_current_language()
             attrname = '%s_%s' % (field, lang)
             return getattr(self_reference, attrname)
         return getter
@@ -111,7 +112,7 @@ class MultilingualModelBase(ModelBase):
     def generate_field_setter(cls, field):
         # Property that masks a setter of the translatable field
         def setter(self_reference, value):
-            lang = self_reference._force_language or get_language().split('-')[0]
+            lang = self_reference._force_language or get_current_language()
             attrname = '%s_%s' % (field, lang)
             setattr(self_reference, attrname, value)
         return setter
@@ -141,14 +142,14 @@ class MultilingualModelBase(ModelBase):
             else:
                 new_ut.append(constraint)
 
-        # Now perform the rewritting
+        # Now perform the re-writing
         for constraint in constraints_to_rewrite:
             for lang in settings.LANGUAGES:
-                language = lang[0]
+                lang_code = lang[0]
                 new_constraint = []
                 for field in constraint:
                     if field in local_trans_fields:
-                        field = get_real_field_name(field, language)
+                        field = get_real_field_name(field, lang_code)
                     new_constraint.append(field)
 
                 new_ut.append(tuple(new_constraint))
@@ -169,7 +170,7 @@ class MultilingualModel(models.Model):
         self._force_language = None
 
         # Rewrite any keyword arguments for translatable fields
-        language = get_language().split('-')[0]
+        language = get_current_language()
         for field in self._meta.translatable_fields:
             if field in kwargs.keys():
                 attrname = get_real_field_name(field, language)
@@ -179,23 +180,25 @@ class MultilingualModel(models.Model):
 
         # We have to force the primary language before initializing or else
         # our "proxy" property will prevent the primary language values from being returned.
-        self._force_language = settings.LANGUAGES[0][0]
+        self._force_language = get_normalized_language(settings.LANGUAGES[0][0])
         super(MultilingualModel, self).__init__(*args, **kwargs)
         self._force_language = None
 
     def save(self, *args, **kwargs):
-        # We have to force the primary language before initializing or else
+        # We have to force the primary language before saving or else
         # our "proxy" property will prevent the primary language values from being returned.
-        self._force_language = settings.LANGUAGES[0][0]
+        old_forced_language = self._force_language
+        self._force_language = get_normalized_language(settings.LANGUAGES[0][0])
         super(MultilingualModel, self).save(*args, **kwargs)
         # Now we can switch back
-        self._force_language = None
+        self._force_language = old_forced_language
 
     def translate(self, language, **kwargs):
         # Temporarily force this objects language
+        old_forced_language = self._force_language
         self._force_language = language
         # Set the values
         for key, val in kwargs.iteritems():
             setattr(self, key, val)  # Set values on the object
         # Now switch back
-        self._force_language = None
+        self._force_language = old_forced_language
